==> Ethna-2.3.7.tgz: Ethna-2.3.7/class/Ethna_ActionError.php <==
<?php
// vim: foldmethod=marker
/**
 *  Ethna_ActionError.php
 *
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
 *  @package    Ethna
 *  @version    $Id: Ethna_ActionError.php 720 2009-02-04 16:14:55Z mumumu-org $
 */

// {{{ Ethna_ActionError
/**
 *  ץꥱ󥨥顼饹
 *
 *  @access     public
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @package    Ethna
 *  @todo   ե򰷤褦ˤ
 */
class Ethna_ActionError
{
    /**#@+
     *  @access private
     */

    /** @var    array   顼֥Ȥΰ */
    var $error_list = array();

    /** @var    object  Ethna_ActionForm    ե४֥ */
    var $action_form = null;

    /** @var    object  Ethna_Logger        ֥ */
    var $logger = null;
    /**#@-*/

    /**
     *  Ethna_ActionError饹Υ󥹥ȥ饯
     *
     *  @access public
     */
    function Ethna_ActionError()
    {
    }

    /**
     *  顼֥Ȥ/ɲä
     *
     *  @access public
     *  @param  string  $name       顼ȯե̾(פʤnull)
     *  @param  string  $message    顼å
     *  @param  int     $code       顼
     *  @return Ethna_Error 顼֥
     */
    function &add($name, $message, $code = null)
    {
        if (func_num_args() > 3) {
            $userinfo = array_slice(func_get_args(), 3);
            $error =& Ethna::raiseNotice($message, $code, $userinfo);
        } else {
            $error =& Ethna::raiseNotice($message, $code);
        }
        $this->addObject($name, $error);
        return $error;
    }

    /**
     *  Ethna_Error֥Ȥɲä
     *
     *  @access public
     *  @param  string              $name   顼бե̾(פʤnull)
     *  @param  object  Ethna_Error $error  顼֥
     */
    function addObject($name, &$error)
    {
        $elt = array();
        $elt['name'] = $name;
        $elt['object'] =& $error;
        $this->error_list[] = $elt;

        // (­)
        $af =& $this->_getActionForm();
        $logger =& $this->_getLogger();
        $logger->log(LOG_NOTICE, '{form} -> [%s]', $this->action_form->getName($name));
    }

    /**
     *  顼֥Ȥο֤
     *
     *  @access public
     *  @return int     顼֥Ȥο
     */
    function count()
    {
        return count($this->error_list);
    }

    /**
     *  顼֥Ȥο֤(count()᥽åɤΥꥢ)
     *
     *  @access public
     *  @return int     顼֥Ȥο
     */
    function length()
    {
        return count($this->error_list);
    }

    /**
     *  Ͽ줿顼֥Ȥƺ
     *
     *  @access public
     */
    function clear()
    {
        $this->error_list = array();
    }

    /**
     *  ꤵ줿եܤ˥顼ȯƤ뤫ɤ֤
     *
     *  @access public
     *  @param  string  $name   ե̾
     *  @return bool    true:顼ȯƤ false:顼ȯƤʤ
     */
    function isError($name)
    {
        foreach ($this->error_list as $error) {
            if (strcasecmp($error['name'], $name) == 0) {
                return true;
            }
        }
        return false;
    }

    /**
     *  ꤵ줿եܤб륨顼å֤
     *
     *  @access public
     *  @param  string  $name   ե̾
     *  @return string  顼å(顼̵null)
     */
    function getMessage($name)
    {
        foreach ($this->error_list as $error) {
            if (strcasecmp($error['name'], $name) == 0) {
                return $this->_getMessage($error);
            }
        }
        return null;
    }

    /**
     *  顼֥Ȥˤ֤
     *
     *  @access public
     *  @return array   顼֥Ȥ
     */
    function getErrorList()
    {
        return $this->error_list;
    }

    /**
     *  顼åˤ֤
     *
     *  @access public
     *  @return array   顼å
     */
    function getMessageList()
    {
        $message_list = array();

        foreach ($this->error_list as $error) {
            $message_list[] = $this->_getMessage($error);
        }
        return $message_list;
    }

    /**
     *  ץꥱ󥨥顼å
     *
     *  @access private
     *  @param  array   顼ȥ
     *  @return string  顼å
     */
    function _getMessage(&$error)
    {
        $af =& $this->_getActionForm();
        $form_name = $af->getName($error['name']);
        return str_replace("{form}", $form_name, $error['object']->getMessage());
    }

    /**
     *  Ethna_ActionForm֥Ȥ
     *
     *  @access private
     *  @return object  Ethna_ActionForm
     */
    function &_getActionForm()
    {
        if (isset($this->action_form) == false) {
            $controller =& Ethna_Controller::getInstance();
            $this->action_form =& $controller->getActionForm();
        }
        return $this->action_form;
    }

    /**
     *  Ethna_Logger֥Ȥ
     *
     *  @access private
     *  @return object  Ethna_Logger
     */
    function &_getLogger()
    {
        if (is_null($this->logger)) {
            $controller =& Ethna_Controller::getInstance();
            $this->logger =& $controller->getLogger();
        }
        return $this->logger;
    }
}
// }}}
?>

==> Ethna-2.5.0.tgz: Ethna-2.5.0/class/Ethna_ActionError.php <==
<?php
// vim: foldmethod=marker
/**
 *  Ethna_ActionError.php
 *
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @license    http://www.opensource.org/licenses/bsd-license.php The BSD License
 *  @package    Ethna
 *  @version    $Id$
 */

// {{{ Ethna_ActionError
/**
 *  アプリケーションエラー管理クラス
 *
 *  @access     public
 *  @author     Masaki Fujimoto <fujimoto@php.net>
 *  @package    Ethna
 *  @todo   配列フォームを扱えるようにする
 */
class Ethna_ActionError
{
    /**#@+
     *  @access private
     */

    /** @var    array   エラーオブジェクトの一覧 */
    var $error_list = array();

    /** @var    object  Ethna_ActionForm    アクションフォームオブジェクト */
    var $action_form = null;

    /** @var    object  Ethna_Logger        ログオブジェクト */
    var $logger = null;
    /**#@-*/

    /**
     *  Ethna_ActionErrorクラスのコンストラクタ
     *
     *  @access public
     */
    function Ethna_ActionError()
    {
    }

    /**
     *  エラーオブジェクトを生成/追加する
     *
     *  @access public
     *  @param  string  $name       エラーの発生したフォーム項目名(不要ならnull)
     *  @param  string  $message    エラーメッセージ
     *  @param  int     $code       エラーコード
     *  @return Ethna_Error エラーオブジェクト
     */
    function &add($name, $message, $code = null)
    {
        if (func_num_args() > 3) {
            $userinfo = array_slice(func_get_args(), 3);
            $error =& Ethna::raiseNotice($message, $code, $userinfo);
        } else {
            $error =& Ethna::raiseNotice($message, $code);
        }
        $this->addObject($name, $error);
        return $error;
    }

    /**
     *  Ethna_Errorオブジェクトを追加する
     *
     *  @access public
     *  @param  string              $name   エラーに対応するフォーム項目名(不要ならnull)
     *  @param  object  Ethna_Error $error  エラーオブジェクト
     */
    function addObject($name, &$error)
    {
        $elt = array();
        $elt['name'] = $name;
        $elt['object'] =& $error;
        $this->error_list[] = $elt;

        // ログ出力(補足)
        $af =& $this->_getActionForm();
        $logger =& $this->_getLogger();
        $logger->log(LOG_NOTICE, '{form} -> [%s]', $this->action_form->getName($name));
    }

    /**
     *  エラーオブジェクトの数を返す
     *
     *  @access public
     *  @return int     エラーオブジェクトの数
     */
    function count()
    {
        return count($this->error_list);
    }

    /**
     *  エラーオブジェクトの数を返す(count()メソッドのエイリアス)
     *
     *  @access public
     *  @return int     エラーオブジェクトの数
     */
    function length()
    {
        return count($this->error_list);
    }

    /**
     *  登録されたエラーオブジェクトを全て削除する
     *
     *  @access public
     */
    function clear()
    {
        $this->error_list = array();
    }

    /**
     *  指定されたフォーム項目にエラーが発生しているかどうかを返す
     *
     *  @access public
     *  @param  string  $name   フォーム項目名
     *  @return bool    true:エラーが発生している false:エラーが発生していない
     */
    function isError($name)
    {
        foreach ($this->error_list as $error) {
            if (strcasecmp($error['name'], $name) == 0) {
                return true;
            }
        }
        return false;
    }

    /**
     *  指定されたフォーム項目に対応するエラーメッセージを返す
     *
     *  @access public
     *  @param  string  $name   フォーム項目名
     *  @return string  エラーメッセージ(エラーが無い場合はnull)
     */
    function getMessage($name)
    {
        foreach ($this->error_list as $error) {
            if (strcasecmp($error['name'], $name) == 0) {
                return $this->_getMessage($error);
            }
        }
        return null;
    }

    /**
     *  エラーオブジェクトを配列にして返す
     *
     *  @access public
     *  @return array   エラーオブジェクトの配列
     */
    function getErrorList()
    {
        return $this->error_list;
    }

    /**
     *  エラーメッセージを配列にして返す
     *
     *  @access public
     *  @return array   エラーメッセージの配列
     */
    function getMessageList()
    {
        $message_list = array();

        foreach ($this->error_list as $error) {
            $message_list[] = $this->_getMessage($error);
        }
        return $message_list;
    }

    /**
     *  アプリケーションエラーメッセージを取得する
     *
     *  @access private
     *  @param  array   エラーエントリ
     *  @return string  エラーメッセージ
     */
    function _getMessage(&$error)
    {
        $af =& $this->_getActionForm();
        $form_name = $af->getName($error['name']);
        return str_replace("{form}", $form_name, $error['object']->getMessage());
    }

    /**
     *  Ethna_ActionFormオブジェクトを取得する
     *
     *  @access private
     *  @return object  Ethna_ActionForm
     */
    function &_getActionForm()
    {
        if (isset($this->action_form) == false) {
            $controller =& Ethna_Controller::getInstance();
            $this->action_form =& $controller->getActionForm();
        }
        return $this->action_form;
    }

    /**
     *  Ethna_Loggerオブジェクトを取得する
     *
     *  @access private
     *  @return object  Ethna_Logger
     */
    function &_getLogger()
    {
        if (is_null($this->logger)) {
            $controller =& Ethna_Controller::getInstance();
            $this->logger =& $controller->getLogger();
        }
        return $this->logger;
    }
}
// }}}
?>
